# Hello Word Counter
Vue是一渐进式的框架，不仅能用于小型项目，也能胜任大型的项目，且学习入手的难度相对其他框架更小。

下面是一个DEMO程序，实现的功能是是在页面上显示Hello Word 且后面显示一个每一秒就会自动+1的一个数字。通过这个例子来快速的上手VUE。
![hello_word_counter](./images/hello_word_counter.gif)

```HTML
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Hello Word</title>
    <!--1.通过CDN加速引入VUE-->
    <script src="https://unpkg.com/vue@next"></script>
</head>
<body>
    <!--2.设置DIV的ID为root -->
    <div id="root"></div>
</body>

<script>
    // 3. 创建VUE的实例
    Vue.createApp({
        // 3.2数据
        data(){
            return{
                num:1
            }
        },
        // 3.3当页面加载完成时会自动执行mounted()
        mounted(){
            // 设置一个定时器每秒将num+1
            setInterval(()=>{
                this.num += 1;
            },1000)
        },
        // 3.1视图模板
        template:'<div> Hello Word!  {{num}}</div>' // 创建模板并渲染到绑定的ID中  <div id="root"><div> Hello Word! </div></div>
    }).mount('#root'); // 标识当前VUE实例作用在ID为root的元素上
</script>
</html>
```
现在来理解一下这个程序:
- 首先通过CDN引入VUE`<script src="https://unpkg.com/vue@next"></script>`
- 然后在`body`中设置一个`div`并指定该`div`的id为**root**;
- 接着在`script`中创建VUE实例，这里是需要重点理解的部分
  - 首先是`Vue.createApp({})`创建Vue实例
  - 然后使用`mount('#root')`将上一步创建的Vue实例绑定到id为**root**的元素上，这样就可以将Vue实例中自定义的内容渲染到id为root的`div`里面
  - 接着关注一下Vue中定义的内容
    - template 定义了需要将什么内容渲染到`id="root"`的DOM元素中，上面代码中国的实例等同于
      ```HTMl
      <body>
          <div id="root">
              <div> Hello Word!  {{num}}</div>
          </div>
      </body>
      ```
      等效于DOM中的`InnerHTML`
      其中的`{{}}`是JS的表达式表明其中的内容不是文本而是一个变量
    - data 定义了当前Vue实例中的使用的数据，也是表达式中变量取值的来源
    - mounted函数会**在Vue实例挂载到`root`节点后(字面理解mount的过去式表完成)**自动执行，在本例中为了实现计数的功能设置了一个每1s执行一次的定时任务，每次将data()中定义的num数值+1，由于页面展示的数字也是从data()中获取的，进而页面展示上的数字也发生了变化。


通过上面的例子可以看出VUE**不再面向DOM编程而是面向数据编程**。
